@@ -6,7 +6,7 @@
 @time:2022/07/13
 """
 
-__all__ = ['main']
+__all__ = ['main', 'db']
 
 if __name__ == '__main__':
     pass
